/* xkeycaps, Copyright (c) 1991, 1992, 1993, 1994, 1995
 * Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the Tektronix LK401 keyboard.
 * By Torbj|rn Lindgren <tl@ae.chalmers.se>
 */

static const KeyCode tek401_codes [] = {

  /* Row 0 */
  15, 23, 106, 39, 47,
  55, 63, 71, 79, 87,
  18, 19, 20, 88,
  89, 135,
  136, 137, 138, 139,

  /* Row 2 */
  22, 30, 38, 46, 45, 54, 62, 69, 70, 78, 77, 86, 93, 110,
  118, 111, 108,
  16, 126, 103, 95,

  /* Row 3 */
  21, 29, 37, 44, 53, 52, 61, 68, 75, 76, 85, 92, 99,
  98,
  109, 119, 117,
  116, 125, 133, 140,

  /* Row 4 */
  25, 28, 36, 35, 43, 51, 60, 59, 67, 74, 83, 84, 90, 91,
  107,
  115, 123, 124, 132,

  /* Row 5 */
  26, 17, 34, 42, 41, 50, 58, 57, 66, 73, 81, 82, 97,
  105, 104, 114,
  113, 122, 130, 129,
  
  /* Row 6 */
  33, 40, 49, 56, 65,
  120, 121
};
